@@ -1,5 +1,5 @@
 
-# $Id: methods.R 229 2008-04-04 11:47:30Z thothorn $
+# $Id: methods.R 255 2009-02-10 15:45:59Z thothorn $
 
 ### methods for `glht' objects
 coef.glht <- function(object, rhs = FALSE, ...) 
@@ -62,3 +62,6 @@ confint.glht <- function(object, parm, level = 0.95, calpha = adjusted_calpha(),
     class(object) <- c("confint.glht", "glht")
     return(object)
 }
+
+cftest <- function(model, ...)
+    summary(glht(model), test = univariate(), ...)
